package demo;

import java.awt.*;
import java.awt.event.*;
import java.io.*;
import javax.swing.*;
import com.japisoft.sc.*;

/**
 * Here a sample of ScEditorKit usage. This application show a toolbar
 * with the following syntax supports :
 * - sql
 * - java
 * - formula
 * User just have to select one and test by inserting a text or loading it
 * @author (c) 2002-2003 JAPISOFT
 * @version 1.0
 * @since 1.0
 * @see JFrame */
public class Demo
    extends JFrame
    implements ActionListener {
    public Demo() {
	super();
	setTitle("Choose a syntax");
	initUI();
	setSize(new Dimension(400, 400));
	setVisible(true);
    }

    private ScEditorKit sc;
    JEditorPane ep;

    private void buildCombo(JComboBox combo, String path) {
	if ( path == null )
	    path = "";
	File f = new File(path);
	if (!f.exists()) {
	    combo.addItem("?");
	}
	else {
	    String[] l = f.list();
	    if (l != null) {
		for (int i = 0; i < l.length; i++) {
		    String prop = l[i];
		    if ( prop.endsWith( ".prop" ) ) {
			int j = prop.indexOf(".");
			if (j > -1) {
			    prop = prop.substring(0, j);
			}
			combo.addItem(prop);
		    }
		}
	    }
	    else {
		combo.addItem("No properties ??");
	    }
	}
    }

    private JComboBox cb;

    private void initUI() {
	ep = new JEditorPane();
	ep.setEditorKit(sc = new ScEditorKit());
	getContentPane().add(new JScrollPane(ep));

	JToolBar jb = new JToolBar();

	cb = new JComboBox();
	buildCombo(cb, System.getProperty("sc.path"));
	cb.addActionListener(this);

	JButton b4 = new JButton("Load sample File...");
	b4.addActionListener(this);
	jb.add(cb);
	jb.add(b4);
	getContentPane().add(jb, BorderLayout.NORTH);
    }

    public void actionPerformed(ActionEvent e) {
	try {
	    if (e.getSource()instanceof JButton) {
		JButton b = (JButton) e.getSource();

		JFileChooser chooser = new JFileChooser(new File(System.getProperty(
										    "user.dir")));
		int returnVal = chooser.showOpenDialog(this);
		if (returnVal == JFileChooser.APPROVE_OPTION) {
		    File f = chooser.getSelectedFile();
		    byte[] data = new byte[ ( int ) f.length()];
		    FileInputStream in = new FileInputStream( f );
		    in.read(data);
		    in.close();
		    ep.setText(new String(data));
		}

	    }
	    else {
		String prop = ( String )cb.getSelectedItem();
		sc.readSyntaxColorDescriptor(new File(System.getProperty("sc.path"),
						      prop + ".prop").toString());

		ep.repaint();
	    }

	}
	catch (Throwable th) {
	    th.printStackTrace();
	}
    }

    public static void main(String[] args) {
	new Demo();
    }
}
